@@ -6,13 +6,19 @@
 #' @param data A data.frame (or tibble). If this data includes columns called
 #'   "blocks", "clusters", and/or "weights", the 'estimatr' package will
 #'   consider them when calculating the difference in means.
-#' @param dinm TRUE calculates a difference in means with uncertainty estimates
+#' @param dinm TRUE calculates a difference in means with uncertainty
+#'   estimates. This option is only available if the `estimatr` package is
+#'   installed. If `data` includes columns named "blocks", "clusters", or
+#'   "weights", this information will be taken into account automatically by
+#'   `estimatr::difference_in_means`.
 #' @param dinm_statistic string: "std.error" or "p.value"
 #' @inheritParams modelsummary
 #' @inheritParams datasummary
 #' @export
 #' @examples
+#' \dontrun{
 #' datasummary_balance(~am, mtcars)
+#' }
 #' @keywords internal
 datasummary_balance <- function(formula,
                                 data,
@@ -26,6 +32,9 @@ datasummary_balance <- function(formula,
                                 dinm_statistic = 'std.error',
                                 ...) {
     
+    # tables does not play well with tibbles
+    data <- as.data.frame(data)
+
     # functions with formatting: str_replace(fmt) doesn't get picked-up by tabular
     MeanF <- function(x) sprintf(fmt, mean(x, na.rm = TRUE))
     SDF <- function(x) sprintf(fmt, stats::sd(x, na.rm = TRUE))
