@@ -5,11 +5,10 @@ clean_stars <- function(stars) {
     if (is.logical(stars)) {
         if (stars) {
             stars <- c('*' = .1, '**' = .05, '***' = .01)
-        }
+        } 
     }
     if (is.numeric(stars)) {
-        stars <- sort(stars, decreasing = TRUE)
-        out <- stars
+        out <- sort(stars, decreasing = TRUE)
     } else {
         out <- NULL
     }
